@@ -1,5 +1,7 @@
 from .exceptions import LoggedError
 
+BUCKET = "aaa-terraform-state"
+
 
 class StorageObjectNotFoundError(LoggedError):
     def __init__(self, obj: str) -> None:
@@ -7,7 +9,7 @@ class StorageObjectNotFoundError(LoggedError):
 
 
 def upload(obj: str) -> None:
-    pass
+    print("Uploading:", obj)
 
 
 def download(obj: str) -> None:
